@@ -1,7 +1,7 @@
 /* CatalystX::CRUD::YUI custom JavaScript 
 
 # sync with .pm files
-my $VERSION = '0.012';   
+my $VERSION = '0.013';   
 
 */
 YAHOO.namespace('crud');
@@ -18,7 +18,7 @@ if (!YAHOO.crud.log) {
             YAHOO.crud.log = function() { window.console.log(arguments[0]) };
         }
         else if (console.debug) {
-            YAHOO.crud.log = console.debug;
+            YAHOO.crud.log = function() { console.log.apply( console, arguments ) };
         }
         else {
             alert("no window.console or console.debug");
